@@ -335,11 +335,14 @@ class StackLocs(Stack):
 
 
 class StackWithId(Stack):
-    def __init__(self, id='id'):
+    def __init__(self, id='id', raise_on_dublicate=True):
         self.id = id
+        self.raise_on_dublicate = raise_on_dublicate
         super().__init__()
 
     def push(self, item, logger=None):
+        if item is None:
+            return
 
         if not isinstance(item, dict):
             raise Exception(f'{item} must be dict')
@@ -355,8 +358,11 @@ class StackWithId(Stack):
 
             return True
         else:
-            raise Exception(f'{item} will be doublicate')
-            # logger.warning(f'{item} will be doublicate')
+            if self.raise_on_dublicate is True:
+                raise Exception(f'{item} will be doublicate')
+            else:
+                if isinstance(logger, Logger):
+                    logger.warning(f'{item} will be doublicate')
 
     def exists(self, id):
         return len(self.find(id)) > 0
